@@ -44,8 +44,8 @@ def convert_layer(node, layer_type, params=None):
             "Unexpected length of kernel_size dimension: {}".format(kernel_size_length)
         )
 
+    pad_layer = None
     if params:
-        pad_layer = None
         weight, bias = extract_params(params)
         kwargs["bias"] = bias is not None
         kwargs["in_channels"] = weight.dims[1] * kwargs.get("groups", 1)
@@ -58,18 +58,23 @@ def convert_layer(node, layer_type, params=None):
             )
 
         # if padding is a layer, remove from kwargs and prepend later
-        if isinstance(kwargs["padding"], nn.Module):
+        if "padding" in kwargs and isinstance(kwargs["padding"], nn.Module):
             pad_layer = kwargs.pop("padding")
 
         # initialize layer and load weights
         layer = layer(**kwargs)
         load_params(layer, weight, bias)
-        if pad_layer is not None:
-            layer = nn.Sequential(pad_layer, layer)
     else:
         # initialize operations without parameters (MaxPool, AvgPool, etc.)
+
+        # if padding is a layer, remove from kwargs and prepend later
+        if "padding" in kwargs and isinstance(kwargs["padding"], nn.Module):
+            pad_layer = kwargs.pop("padding")
         layer = layer(**kwargs)
 
+    if pad_layer is not None:
+        layer = nn.Sequential(pad_layer, layer)
+
     return layer
 
 
@@ -80,8 +85,8 @@ def convert_batch_norm_layer(node, params):
     kwargs["num_features"] = params[0].dims[0]
     # initialize layer and load weights
     layer = layer(**kwargs)
-    key = ["weight", "bias", "running_mean", "running_var"]
-    for key, value in zip(key, params):
+    keys = ["weight", "bias", "running_mean", "running_var"]
+    for key, value in zip(keys, params):
         getattr(layer, key).data = torch.from_numpy(numpy_helper.to_array(value))
 
     return layer
@@ -95,8 +100,8 @@ def convert_instance_norm_layer(node, params):
     kwargs["num_features"] = params[0].dims[0]
     # initialize layer and load weights
     layer = layer(**kwargs)
-    key = ["weight", "bias"]
-    for key, value in zip(key, params):
+    keys = ["weight", "bias"]
+    for key, value in zip(keys, params):
         getattr(layer, key).data = torch.from_numpy(numpy_helper.to_array(value))
 
     return layer
