@@ -1,5 +1,6 @@
 from .add import Add
 from .batchnorm import BatchNormUnsafe
+from .expand import Expand
 from .instancenorm import InstanceNormUnsafe
 from .cast import Cast
 from .constant import ConstantOfShape
@@ -8,16 +9,19 @@ from .gather import Gather
 from .onehot import OneHot
 from .pad import Pad
 from .pooling import GlobalAveragePool
+from .range import Range
 from .reshape import Reshape
 from .shape import Shape
 from .slice import Slice
 from .split import Split
 from .squeeze import Squeeze
 from .resize import Resize, Upsample
+from .unsqueeze import Unsqueeze
 
 __all__ = [
     "Add",
     "BatchNormUnsafe",
+    "Expand",
     "InstanceNormUnsafe",
     "Cast",
     "ConstantOfShape",
@@ -26,11 +30,13 @@ __all__ = [
     "OneHot",
     "Pad",
     "GlobalAveragePool",
+    "Range",
     "Reshape",
     "Shape",
     "Slice",
     "Split",
     "Squeeze",
     "Resize",
+    "Unsqueeze",
     "Upsample",
 ]
